FlutterFawryPayPlatform class abstract
The interface that implementations of flutter_fawry_pay must implement.
Platform implementations should extend this class rather than implement it as flutter_fawry_pay
does not consider newly added methods to be breaking changes. Extending this class
(using extends) ensures that the subclass will get the default implementation, while
platform implementations that implements this interface will be broken by newly added
FlutterFawryPayPlatform methods.
- Inheritance
-
- Object
- PlatformInterface
- FlutterFawryPayPlatform
- Implementers
Constructors
- FlutterFawryPayPlatform()
- Constructs a FlutterFawryPayPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callbackResultStream(
) → Stream - Stream to return resulted data.
-
init(
{required String merchantID, Style style = Style.STYLE1, bool enableLogging = false, bool enableMockups = false, bool skipCustomerInput = false, String? username, String? email, String? webCustomerName, Language language = Language.EN, Environment environment = Environment.TEST, DisplayMode webDisplayMode = DisplayMode.POPUP}) → Future< bool> - Init FawryPay SDK services.
-
initialize(
{required List< FawryItem> items, String? merchantRefNumber, String? customerProfileId, int? paymentExpiry, String? returnUrl, bool? authCaptureModePayment, Map<String, dynamic> ? customParam}) → Future<bool> - Initialize FawryPay payment charge.
-
initializeCardTokenizer(
{required String customerMobile, required String customerEmail, String? customerProfileId, String? merchantRefNumber, Map< String, dynamic> ? customParam}) → Future<bool> - Initialize Card Tokenizer.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
randomAlphaNumeric(
int count) → String -
reset(
) → Future< bool> - Reset FawryPay SDK Payment.
-
startProcess(
) → Future< FawryResponse> - Start FawryPay SDK process.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterFawryPayPlatform
-
The default instance of FlutterFawryPayPlatform to use.
getter/setter pair